km3pipe.io.DAQPump
==================

.. currentmodule:: km3pipe.io

.. autoclass:: DAQPump

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DAQPump.__init__
      ~DAQPump.add
      ~DAQPump.close
      ~DAQPump.close_file
      ~DAQPump.configure
      ~DAQPump.determine_frame_positions
      ~DAQPump.expose
      ~DAQPump.finish
      ~DAQPump.get
      ~DAQPump.get_blob
      ~DAQPump.next
      ~DAQPump.next_blob
      ~DAQPump.open_file
      ~DAQPump.pre_finish
      ~DAQPump.process
      ~DAQPump.require
      ~DAQPump.rewind_file
      ~DAQPump.seek_to_frame
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DAQPump.name
   
   